'use strict';

import React from "react";
import PropTypes from "prop-types";

import I18nWrapper from "../i18n/I18nWrapper";
import injectIntl from "../utils/injectIntl";
import Input from "./Input";

class Select extends React.Component {

    constructor(props) {
        super(props);
        this.i18n = props.i18n;
    }

    focus() {
        this.select.focus();
    }

    _generateOptions() {
        const options = [];
        for (let i = 0, len = this.props.options.length; i < len; i++) {
            const option = this.props.options[i];
            options.push(<option key={'opt_' + option.value} value={option.value} title={option.title}>
                {option.label}
            </option>);
        }
        return options;
    }

    render() {
        const options = this._generateOptions();
        if (this.props.addDefault) {
            options.unshift(<option key='opt_default' value='' disabled style={{display: 'none'}}>
                {this.i18n('select.default')}
            </option>);
        }
        return <Input ref={c => this.select = c} type='select' name={this.props.name} title={this.props.title}
                      label={this.props.label} value={this.props.value ? this.props.value : ''}
                      onChange={this.props.onChange}>
            {options}
        </Input>;
    }
}

Select.propTypes = {
    options: PropTypes.array,
    name: PropTypes.string,
    title: PropTypes.string,
    label: PropTypes.string,
    onChange: PropTypes.func,
    addDefault: PropTypes.bool    // Specifies whether the default '----Select----' option should be added
};

export default injectIntl(I18nWrapper(Select));
